@@ -20,10 +20,11 @@ exports.permissions = require('./permissions')
 exports.init = function (sbot, opts) {
 
   var api = {}
-  var phoenixdb = sbot.sublevel('patchwork')
+  var patchworkdb = sbot.sublevel('patchwork')
   var db = {
-    isread: phoenixdb.sublevel('isread'),
-    bookmarked: phoenixdb.sublevel('bookmarked')
+    isread: patchworkdb.sublevel('isread'),
+    bookmarked: patchworkdb.sublevel('bookmarked'),
+    channelpinned: patchworkdb.sublevel('channelpinned')
   }
   var state = {
     // indexes (lists of {key:, ts:})
@@ -32,6 +33,7 @@ exports.init = function (sbot, opts) {
     inbox: u.index('inbox'),
     bookmarks: u.index('bookmarks'),
     notifications: u.index('notifications'),
+    // other indexes: channel-* are created as needed
 
     // views
     profiles: {},
@@ -84,6 +86,19 @@ exports.init = function (sbot, opts) {
     )
   )
 
+  // load channelpins into indexes
+  state.pinc()
+  pull(
+    pl.read(db.channelpinned, { keys: true, values: true }),
+    pull.drain(function (pin) {
+      if (typeof pin.key === 'string') {
+        var index = getChannelIndex(pin.key)
+        index.pinned = pin.value
+      }
+    },
+    function () { state.pdec() })
+  )
+
   // setup sbot log processor
   var processor = require('./processor')(sbot, db, state, emit)
   pull(pl.read(sbot.sublevel('log'), { live: true, onSync: onHistorySync }), pull.drain(processor))
@@ -134,28 +149,31 @@ exports.init = function (sbot, opts) {
 
   api.getIndexCounts = function (cb) {
     awaitSync(function () {
-      cb(null, {
+      var counts = {
         inbox: state.inbox.rows.length,
         inboxUnread: state.inbox.filter(function (row) { return !row.isread }).length,
         bookmarks: state.bookmarks.rows.length,
         bookmarksUnread: state.bookmarks.filter(function (row) { return !row.isread }).length,
         notificationsUnread: state.notifications.countUntouched()
-      })
+      }
+      for (var k in state) {
+        if (k.indexOf('channel-') === 0)
+          counts[k] = state[k].rows.length
+      }
+      cb(null, counts)
     })
   }
 
-  api.createNewsfeedStream = indexStreamFn(state.newsfeed, function (row) { 
-    return row.key
-  })
-  api.createInboxStream = indexStreamFn(state.inbox, function (row) { 
-    return row.key
-  })
-  api.createBookmarkStream = indexStreamFn(state.bookmarks, function (row) { 
-    return row.key
-  })
-  api.createNotificationsStream = indexStreamFn(state.notifications, function (row) { 
-    return row.key
-  })
+  api.createNewsfeedStream = indexStreamFn(state.newsfeed)
+  api.createInboxStream = indexStreamFn(state.inbox)
+  api.createBookmarkStream = indexStreamFn(state.bookmarks)
+  api.createNotificationsStream = indexStreamFn(state.notifications)
+  api.createChannelStream = function (channel, opts) {
+    if (typeof channel !== 'string' || !channel.trim())
+      return cb(new Error('Invalid channel'))
+    var index = getChannelIndex(channel)
+    return indexStreamFn(index)(opts)
+  }
 
   function indexMarkRead (indexname, key, keyname) {
     if (Array.isArray(key)) {
@@ -288,6 +306,54 @@ exports.init = function (sbot, opts) {
     })
   }
 
+  function getChannelIndex (channel) {
+    var k = 'channel-'+channel
+    var index = state[k]
+    if (!index)
+      index = state[k] = u.index(k)
+    return index
+  }
+  api.getChannels = function (cb) {
+    awaitSync(function () {
+      var channels = []
+      for (var k in state) {
+        if (k.indexOf('channel-') === 0) {
+          var lastUpdated = (state[k].rows[0]) ? state[k].rows[0].ts : 0
+          channels.push({
+            name: k.slice('channel-'.length),
+            lastUpdated: lastUpdated,
+            pinned: state[k].pinned
+          })
+        }
+      }
+      cb(null, channels)
+    })
+  }
+  api.pinChannel = function (channel, cb) {
+    var index = getChannelIndex(channel)
+    index.pinned = true
+    db.channelpinned.put(channel, 1, cb)
+    emit('channelpinned', { channel: channel, value: true })
+  }
+  api.unpinChannel = function (channel, cb) {
+    var index = getChannelIndex(channel)
+    index.pinned = false
+    db.channelpinned.del(channel, cb) 
+    emit('channelpinned', { channel: channel, value: false })
+  }
+  api.toggleChannelPinned = function (channel, cb) {
+    var index = getChannelIndex(channel)
+    if (index.pinned) {
+      api.unpinChannel(channel, function (err) {
+        cb(err, true)
+      })
+    } else {
+      api.pinChannel(channel, function (err) {
+        cb(err, false)
+      })
+    }
+  }
+
   api.addFileToBlobs = function (path, cb) {
     pull(
       toPull.source(fs.createReadStream(path)),
@@ -424,7 +490,6 @@ exports.init = function (sbot, opts) {
     return function (opts) {
       var lastAccessed = index.lastAccessed
       index.touch()
-      emit('index-change', { index: index.name })
 
       // emulate the `ssb.createFeedStream` interface
       var lt      = o(opts, 'lt')
