@@ -79,7 +79,7 @@ export class NiceDate extends React.Component {
 
 // parent class for components which should persist their state to localstorage
 // - subclasses must call super(props, storageId), where `storageId` is the localStorage key
-// - subclasses can also set defaultState to ensure certain values
+// - subclasses should provide defaultState to set which values are persisted, and give initial values
 export class LocalStoragePersistedComponent extends React.Component {
   constructor(props, storageId, defaultState) {
     super(props)
@@ -90,18 +90,22 @@ export class LocalStoragePersistedComponent extends React.Component {
     catch(e) { this.state = {} }
 
     // write any missing state props from default state
-    if (defaultState) {
-      for (var k in defaultState) {
-        if (!(k in this.state))
-          this.state[k] = defaultState[k]
-      }
+    this.persistKeys = Object.keys(defaultState)
+    for (var k in defaultState) {
+      if (!(k in this.state))
+        this.state[k] = defaultState[k]
     }
   }
 
   setState(obj, cb) {
     // override to persist to local storage
     super.setState(obj, (prevState, currentProps) => {
-      localStorage[this.storageId] = JSON.stringify(this.state)
+      // extract only the persisted keys
+      var saveState = {}
+      this.persistKeys.forEach(k => saveState[k] = this.state[k])
+
+      // store
+      localStorage[this.storageId] = JSON.stringify(saveState)
       cb && cb(prevState, currentProps)
     })
   }
