@@ -193,6 +193,7 @@ export default class MsgList extends React.Component {
     let opts = (typeof this.props.live == 'object') ? this.props.live : {}
     opts.threads = true
     opts.live = true
+    opts.old = false
     this.liveStream = source(opts)
     pull(
       this.liveStream,
@@ -391,7 +392,7 @@ export default class MsgList extends React.Component {
                     lastDate = moment(lastPost.value.timestamp)
                     if (this.props.dateDividers && !lastDate.isSame(oldLastDate, 'day')) {
                       let label = (lastDate.isSame(endOfToday, 'day')) ? 'today' : lastDate.endOf('day').from(endOfToday)
-                      return <div key={m.key}><hr className="msgs-divider" data-label={label} />{item}</div>
+                      return <div key={m.key}><hr className="labeled" data-label={label} />{item}</div>
                     }
                     return item
                   }) }
