@@ -9,7 +9,10 @@ export default class Channels extends React.Component {
   constructor(props) {
     super(props)
     this.state = { channels: app.channels||[] }
-    app.on('update:channels', () => this.setState({ channels: app.channels }))
+    app.on('update:channels', (this.onUpdateChannels = () => this.setState({ channels: app.channels })))
+  }
+  componentWillUnmount() {
+    app.removeListener('update:channels', this.onUpdateChannels)
   }
   onSelect(channel) {
     app.history.pushState(null, '/newsfeed/channel/' + encodeURIComponent(channel.name))
