@@ -3,6 +3,7 @@ import React from 'react'
 import { Link } from 'react-router'
 import pull from 'pull-stream'
 import mlib from 'ssb-msgs'
+import cls from 'classnames'
 import { LocalStoragePersistedComponent } from '../com'
 import Dipswitch from '../com/form-elements/dipswitch'
 import Tabs from '../com/tabs'
@@ -26,14 +27,23 @@ function followedOnlyFilter (msg) {
   return msg.value.author === app.user.id || social.follows(app.user.id, msg.value.author)
 }
 
+function findChannelData (channels, name) {
+  for (var i=0; i < channels.length; i++) {
+    if (channels[i].name === name)
+      return channels[i]
+  }
+  return null
+}
+
+// lefthand nav helper component
 class Nav extends React.Component {
   render() {
     // predicates
     const isPinned = b => channel => (!!channel.pinned == b)
     
     // lists
-    const pinnedChannels = app.channels.filter(isPinned(true))
-    const unpinnedChannels = app.channels.filter(isPinned(false)).slice(0, 10)
+    const pinnedChannels = this.props.channels.filter(isPinned(true))
+    const unpinnedChannels = this.props.channels.filter(isPinned(false)).slice(0, 10)
 
     // render
     const NavHeading = props => {
@@ -62,12 +72,17 @@ export default class NewsFeed extends LocalStoragePersistedComponent {
     super(props, 'newsfeedState', {
       isToolbarOpen: true,
       listItemIndex: 0,
-      isFollowedOnly: false,
+      isFollowedOnly: true,
       isUsingThreadPanel: false,
       currentThreadKey: null
     })
 
-    this.onOpenMsg = key => {
+    // watch for updates to the channels
+    this.state.channels = app.channels || []
+    app.on('update:channels', (this.onUpdateChannels = () => this.setState({ channels: app.channels })))
+
+    // watch for open:msg events
+    app.on('open:msg', (this.onOpenMsg = key => {
       if (this.state.isUsingThreadPanel) {
         // show in the panel
         this.setState({ currentThreadKey: key })
@@ -75,58 +90,88 @@ export default class NewsFeed extends LocalStoragePersistedComponent {
         // navigate
         app.history.pushState(null, '/msg/' + encodeURIComponent(key))
       }      
-    }
-    app.on('open:msg', this.onOpenMsg)
+    }))
   }
   componentWillUnmount() {
+    app.removeListener('update:channels', this.onUpdateChannels)
     app.removeListener('open:msg', this.onOpenMsg)
   }
 
-  cursor (msg) {
-    if (msg)
-      return [msg.value.timestamp, msg.value.author]
-  }
-
-  onToggleToolbar() {
-    this.setState({ isToolbarOpen: !this.state.isToolbarOpen }, () => {
+  // ui event handlers
+  onToggleToolbar(b) {
+    this.setState({ isToolbarOpen: b }, () => {
       this.refs.list.calcContainerHeight()
     })
   }
-
   onSelectListItem(listItem) {
     this.setState({ listItemIndex: LISTITEMS.indexOf(listItem) })
   }
-
   onToggleFollowedOnly(b) {
     this.setState({ isFollowedOnly: b }, () => {
       this.refs.list.reload()
     })
   }
-
   onToggleThreadPanel(b) {
     this.setState({ isUsingThreadPanel: b })
   }
+  onTogglePinned() {
+    const channel = this.props.params.channel
+    if (!channel)
+      return
+    app.ssb.patchwork.toggleChannelPinned(channel, err => {
+      if (err)
+        app.issue('Failed to pin channel', err)
+    })
+  }
 
   render() {
     const channel = this.props.params.channel
+    const channelData = channel && findChannelData(this.state.channels, channel)
     const listItem = LISTITEMS[this.state.listItemIndex]
     const ListItem = listItem.Component
     const Hero = (props) => {
+      // render channel pin buttons
+      var pinBtn, pinToolbarBtn
+      if (channel) {
+        const isPinned = channelData && channelData.pinned
+        if (isPinned) {
+          pinBtn = <a className="selected" title="Pinned" onClick={this.onTogglePinned.bind(this, false)}><i className="fa fa-thumb-tack" /></a>
+          pinToolbarBtn = <Dipswitch label="Pinned Channel" checked={true} onToggle={this.onTogglePinned.bind(this)} />
+        } else {
+          pinBtn = <a title="Pin" onClick={this.onTogglePinned.bind(this, true)}><i className="fa fa-thumb-tack" /></a>
+          pinToolbarBtn = <Dipswitch label="Pin Channel" checked={false} onToggle={this.onTogglePinned.bind(this)} />
+        }
+      }
+
+      // render toolbar
+      var toolbar, toolbarBtn
       if (this.state.isToolbarOpen) {
-        return <div className="toolbar">
-          <a className="btn" onClick={this.onToggleToolbar.bind(this)}><i className="fa fa-check" /> Done</a>
-          <span className="divider" />
+        toolbar = <div className="toolbar">
           <Dipswitch label={this.state.isFollowedOnly?"Followed Only":"All Users"} checked={this.state.isFollowedOnly} onToggle={this.onToggleFollowedOnly.bind(this)} />
           <span className="divider" />
           <Dipswitch label={this.state.isUsingThreadPanel?"Preview Threads":"Navigate to Threads"} checked={this.state.isUsingThreadPanel} onToggle={this.onToggleThreadPanel.bind(this)} />
           <span className="divider" />
           <Tabs options={LISTITEMS} selected={listItem} onSelect={this.onSelectListItem.bind(this)} />
+          { (channel) ? <span className="divider" /> : ''}
+          { pinToolbarBtn }
         </div>
-      } else {
-        return <div className="toolbar floating">
-          <a className="btn" onClick={this.onToggleToolbar.bind(this)}><i className="fa fa-wrench" /></a>
-        </div>
-      }
+        toolbarBtn = <a className="selected" onClick={this.onToggleToolbar.bind(this, false)}><i className="fa fa-cog" /></a>
+      } else 
+        toolbarBtn = <a onClick={this.onToggleToolbar.bind(this, true)}><i className="fa fa-cog" /></a>
+
+      // render hero
+      return <div className="hero">
+        <h1>{ channel ? <span><i className="fa fa-hashtag" /> {channel}</span> : 'All' } <small>{pinBtn} {toolbarBtn}</small></h1>
+        <div>Public messages by everyone { this.state.isFollowedOnly ? 'that you follow' : 'in your network' }.</div>
+        {toolbar}
+        <hr className="labeled" data-label="compose" />
+      </div>
+    }
+
+    // msg-list params
+    const cursor = msg => {
+      if (msg)
+        return [msg.value.timestamp, msg.value.author]
     }
     const source = (opts) => {
       if (channel) 
@@ -139,6 +184,7 @@ export default class NewsFeed extends LocalStoragePersistedComponent {
       return true
     }
 
+    // render all
     const thread = this.state.currentThreadKey
     return <div id="newsfeed" key={channel||'*'}>
       <MsgList
@@ -150,12 +196,12 @@ export default class NewsFeed extends LocalStoragePersistedComponent {
         openMsgEvent
         filter={filter}
         Hero={Hero}
-        LeftNav={Nav} leftNavProps={{ location: this.props.location }}
+        LeftNav={Nav} leftNavProps={{ location: this.props.location, channels: this.state.channels }}
         ListItem={ListItem}
         live={{ gt: [Date.now(), null] }}
         emptyMsg={(channel) ? ('No posts on "'+channel+'"... yet!') : 'Your newsfeed is empty.'}
         source={source}
-        cursor={this.cursor} />
+        cursor={cursor} />
       { this.state.isUsingThreadPanel && this.state.currentThreadKey ? <Thread key={thread} id={thread} closeBtn live /> : '' }
     </div>
   }
